SNWA=function(path, data_separ,masking,mask_path,mask_separ,regress_separ,decomposition_separ,decomposition_method, automatic_decomposition, decomposition_file, alpha=0.05, MCPprocedure="bonferroni",testType = "parametric", permutations = 10000, paired=FALSE, summaryFunctionName="mean", binarize, weighted, alternative="two.sided", plotResults=FALSE, regressors_file=NULL,regress = FALSE, WieghtsMatrix=1, option="one region to one region"){

if(weighted==FALSE){
weighted = NULL}

library(igraph)
source(paste(connectomeAnalyzerPath,'loadData.r',sep=""))
data = loadData(path,separ=data_separ,masking,mask_path,mask_separ)

if(binarize){
dataGroup1 = data$dataGroup1
dataGroup2 = data$dataGroup2
dataGroup1[dataGroup1 > 0 | dataGroup1 < 0] = 1
dataGroup2[dataGroup2 > 0 | dataGroup2 < 0] = 1
data$dataGroup1 = dataGroup1
data$dataGroup2 = dataGroup2
}

SubregionsIndices=NULL
if(decomposition_method == 'File')
{source(paste(connectomeAnalyzerPath,"load_subregions.r", sep=""))
SubregionsIndices=loadSubregions(decomposition_file,decomposition_separ)}
else
{
	if(decomposition_method == 'Automatic')
	{
		source(paste(connectomeAnalyzerPath,"decomposition.r", sep=""))
		SubregionsIndices=decomposition(data,automatic_decomposition)
	}
	else
	{print('Unknown decomposition method')}
}
source(paste(connectomeAnalyzerPath,"SummaryFunctions.r", sep=""))
summaryFunction=get(summaryFunctionName) #mean
s=length(unique(SubregionsIndices[,1]))

source(paste(connectomeAnalyzerPath,"reduceData3.r", sep=""))

reducedGroup1=reduceData3(data$dataGroup1, summaryFunction=summaryFunction, SubregionsIndices,option=option, weighted = weighted)$reducedData
reducedGroup2=reduceData3(data$dataGroup2, summaryFunction=summaryFunction, SubregionsIndices,option=option, weighted = weighted)$reducedData

regressors = NULL
if(regress){
	source(paste(connectomeAnalyzerPath,"load_regressors.r",sep=""))
	regressors = loadRegressors(regressors_file,regress_separ,data$names)
	reducedData = NULL
	reducedData$dataGroup1 = reducedGroup1
	reducedData$dataGroup2 = reducedGroup2
	source(paste(connectomeAnalyzerPath,"regress_data.r", sep=""))
	regressedData = regress_data(reducedData,regressors)
	reducedGroup1=regressedData$dataGroup1
	reducedGroup2=regressedData$dataGroup2
	regressors = NULL
}

source(paste(connectomeAnalyzerPath,"computeMatrixPvalues.r", sep=""))

matrixOfPval=computeMatrixPvalues(reducedGroup1,reducedGroup2,option=option,connectomeAnalyzerPath=connectomeAnalyzerPath,testType = testType, permutations = permutations, paired=paired, alternative=alternative,regressors=regressors)
#print(min(matrixOfPval$MatrixOfPvalues))

source(paste(connectomeAnalyzerPath,"getThreshold.r", sep=""))

out=getThreshold(MatrixOfPvalues=matrixOfPval, alpha=alpha,WieghtsMatrix=WieghtsMatrix, MCPprocedure=MCPprocedure,option=option)
BlockPvalues=matrixOfPval$MatrixOfPvalues
ResultsMatrix=matrixOfPval$MatrixOfPvalues<=out$threshold
print(summaryFunctionName)
print ("The number of rejections is")
R=(sum(ResultsMatrix)/2+sum(diag(ResultsMatrix))/2)
print(R)
if (R>0){
#print(ResultsMatrix)
if (file.exists(paste(path,"/Results",sep=""))==FALSE){
dir.create(paste(path,"/Results",sep=""))
}


write.table(ResultsMatrix, paste(path, "/Results/",summaryFunctionName,"_", MCPprocedure,"_",alternative,"_alpha-",alpha,"_",testType,"_SNWA.csv", sep=""))

if (plotResults==TRUE){
library(igraph)
g=graph.adjacency(matrix(as.numeric(ResultsMatrix), ncol=dim(ResultsMatrix)[1]))
g=graph.adjacency(matrix(as.numeric(ResultsMatrix), ncol=dim(ResultsMatrix)[1]))
V(g)$label=as.character(1:s)
V(g)$color="red"
V(g)$size=6
V(g)$frame.color="red"
E(g)$color="grey70"
E(g)$weight=5
png(paste(path, "/Results/",summaryFunctionName,"_", MCPprocedure,"_",alternative,"_","SNWA.png", sep=""),width = 960, height = 960,
    units = "px", pointsize = 12, bg = "white", res = NA)
plot(g,layout=layout.circle)
dev.off()
}
}
SWAresults=NULL
SWAresults$BlockPvalues=BlockPvalues
SWAresults$BlocResultsMatrix=ResultsMatrix
SWAresults$R=R
return(SWAresults)
}
